pub fn with_tooltip<'a, Message: 'a>(
content: impl Into<Element<'a, Message>>,
label: impl IntoFragment<'a>,
) -> Element<'a, Message>Expand description
Wraps a widget in a tooltip with a readable styled container.
pub fn with_tooltip<'a, Message: 'a>(
content: impl Into<Element<'a, Message>>,
label: impl IntoFragment<'a>,
) -> Element<'a, Message>Wraps a widget in a tooltip with a readable styled container.